@@ -394,7 +394,7 @@ sub flymakeFile {
         my $rhConfigRun = $self->rhRunFile(
             file => $file,
             rhConfigType =>  {
-                command => q{perl -c ${INC} "${SOURCE_FILE}" 2>&1 | perl -ne " /Subroutine \\w+ redefined at/ or print"},
+                command => q{perl -c ${INC} "${SOURCE_FILE}" 2>&1 | perl -ne " /Subroutine [\\w:]+ redefined at/ or print"},
                 moniker => "Flymake",
                 rex => "",
                 run_from => "file_directory",
